@@ -30,27 +30,19 @@
  *
  ******************************************************************************/
 #include "gtest/gtest.h"
-// workaround to eliminate the compiling warning on linux
-// The macro will conflict with definition in gtest.h
-#ifdef __USE_GNU
-#undef __USE_GNU  // defined in EbThreads.h
-#endif
-#ifdef _GNU_SOURCE
-#undef _GNU_SOURCE  // defined in EbThreads.h
-#endif
-#include "EbDefinitions.h"
-#include "EbUtility.h"
+#include "definitions.h"
+#include "utility.h"
 #include "aom_dsp_rtcd.h"
 #include "random.h"
 #include "convolve.h"
 #include "util.h"
-#include "EbEncInterPrediction.h"
+#include "enc_inter_prediction.h"
 
 using std::make_tuple;
 using svt_av1_test_tool::SVTRandom;
 
 #define MAX_MASK_SQUARE (4 * MAX_SB_SQUARE)
-#define MAKE_PARAM(func_type) std::tuple<func_type, func_type, const char *>
+#define MAKE_PARAM(func_type) std::tuple<func_type, func_type>
 
 namespace {
 template <typename SrcSample, typename DstSample, typename BlendFunc,
@@ -58,7 +50,6 @@ template <typename SrcSample, typename DstSample, typename BlendFunc,
 class CompBlendTest : public ::testing::TestWithParam<BlendTestParam> {
   public:
     CompBlendTest() {
-        tst_fn_name = "";
         func_ref_ = nullptr;
         func_tst_ = nullptr;
         no_sub_ = false;
@@ -123,8 +114,6 @@ class CompBlendTest : public ::testing::TestWithParam<BlendTestParam> {
                             for (int j = 0; j < w_; ++j) {
                                 ASSERT_EQ(tst_dst_[i * dst_stride_ + j],
                                           ref_dst_[i * dst_stride_ + j])
-                                    << "Mismatch at unit tests for "
-                                    << tst_fn_name << "\n"
                                     << " Pixel mismatch at index "
                                     << "[" << j << "x" << i
                                     << "]\nblock size: " << block_size
@@ -170,7 +159,6 @@ class LbdCompBlendTest
         bd_ = 8;
         func_ref_ = TEST_GET_PARAM(0);
         func_tst_ = TEST_GET_PARAM(1);
-        tst_fn_name = TEST_GET_PARAM(2);
     }
 
     void run_blend(int subw, int subh) override {
@@ -205,14 +193,27 @@ TEST_P(LbdCompBlendTest, BlendA64Mask) {
     run_test();
 }
 
-INSTANTIATE_TEST_CASE_P(
-    BLEND, LbdCompBlendTest,
-    ::testing::ValuesIn({
-        make_tuple(svt_aom_blend_a64_mask_c, svt_aom_blend_a64_mask_avx2,
-                   "svt_aom_blend_a64_mask_avx2"),
-        make_tuple(svt_aom_blend_a64_mask_c, svt_aom_blend_a64_mask_sse4_1,
-                   "svt_aom_blend_a64_mask_sse4_1"),
-    }));
+#ifdef ARCH_X86_64
+INSTANTIATE_TEST_SUITE_P(SSE4_1, LbdCompBlendTest,
+                         ::testing::ValuesIn({
+                             make_tuple(svt_aom_blend_a64_mask_c,
+                                        svt_aom_blend_a64_mask_sse4_1),
+                         }));
+
+INSTANTIATE_TEST_SUITE_P(AVX2, LbdCompBlendTest,
+                         ::testing::ValuesIn({
+                             make_tuple(svt_aom_blend_a64_mask_c,
+                                        svt_aom_blend_a64_mask_avx2),
+                         }));
+#endif  // ARCH_X86_64
+
+#ifdef ARCH_AARCH64
+INSTANTIATE_TEST_SUITE_P(NEON, LbdCompBlendTest,
+                         ::testing::ValuesIn({
+                             make_tuple(svt_aom_blend_a64_mask_c,
+                                        svt_aom_blend_a64_mask_neon),
+                         }));
+#endif  // ARCH_AARCH64
 
 using LbdBlendA64D16MaskFunc = void (*)(uint8_t *, uint32_t,
                                         const CONV_BUF_TYPE *, uint32_t,
@@ -228,7 +229,6 @@ class LbdCompBlendD16Test
         bd_ = 10;
         func_ref_ = TEST_GET_PARAM(0);
         func_tst_ = TEST_GET_PARAM(1);
-        tst_fn_name = TEST_GET_PARAM(2);
     }
 
     void run_blend(int subw, int subh) override {
@@ -268,14 +268,23 @@ TEST_P(LbdCompBlendD16Test, BlendA64MaskD16) {
     run_test();
 }
 
-INSTANTIATE_TEST_CASE_P(
-    BLEND, LbdCompBlendD16Test,
+#ifdef ARCH_X86_64
+INSTANTIATE_TEST_SUITE_P(
+    SSE4_1, LbdCompBlendD16Test,
     ::testing::ValuesIn({make_tuple(svt_aom_lowbd_blend_a64_d16_mask_c,
-                                    svt_aom_lowbd_blend_a64_d16_mask_sse4_1,
-                                    "svt_aom_lowbd_blend_a64_d16_mask_sse4_1"),
-                         make_tuple(svt_aom_lowbd_blend_a64_d16_mask_c,
-                                    svt_aom_lowbd_blend_a64_d16_mask_avx2,
-                                    "svt_aom_lowbd_blend_a64_d16_mask_avx2")}));
+                                    svt_aom_lowbd_blend_a64_d16_mask_sse4_1)}));
+INSTANTIATE_TEST_SUITE_P(
+    AVX2, LbdCompBlendD16Test,
+    ::testing::ValuesIn({make_tuple(svt_aom_lowbd_blend_a64_d16_mask_c,
+                                    svt_aom_lowbd_blend_a64_d16_mask_avx2)}));
+#endif  // ARCH_X86_64
+
+#ifdef ARCH_AARCH64
+INSTANTIATE_TEST_SUITE_P(
+    NEON, LbdCompBlendD16Test,
+    ::testing::ValuesIn({make_tuple(svt_aom_lowbd_blend_a64_d16_mask_c,
+                                    svt_aom_lowbd_blend_a64_d16_mask_neon)}));
+#endif  // ARCH_AARCH64
 
 using LbdBlendA64HMaskFunc = void (*)(uint8_t *, uint32_t, const uint8_t *,
                                       uint32_t, const uint8_t *, uint32_t,
@@ -289,7 +298,6 @@ class LbdCompBlendHMaskTest
         bd_ = 8;
         func_ref_ = TEST_GET_PARAM(0);
         func_tst_ = TEST_GET_PARAM(1);
-        tst_fn_name = TEST_GET_PARAM(2);
         no_sub_ = true;
     }
 
@@ -326,13 +334,24 @@ TEST_P(LbdCompBlendHMaskTest, BlendA64Mask) {
     run_test();
 }
 
-INSTANTIATE_TEST_CASE_P(
-    BLEND, LbdCompBlendHMaskTest,
-    ::testing::ValuesIn(
-        {make_tuple(svt_aom_blend_a64_hmask_c, svt_aom_blend_a64_hmask_sse4_1,
-                    "svt_aom_blend_a64_hmask_sse4_1"),
-         make_tuple(svt_aom_blend_a64_hmask_c, svt_av1_blend_a64_hmask_avx2,
-                    "svt_dav1d_blend_a64_hmask_avx2")}));
+#ifdef ARCH_X86_64
+INSTANTIATE_TEST_SUITE_P(
+    SSE4_1, LbdCompBlendHMaskTest,
+    ::testing::ValuesIn({make_tuple(svt_aom_blend_a64_hmask_c,
+                                    svt_aom_blend_a64_hmask_sse4_1)}));
+
+INSTANTIATE_TEST_SUITE_P(
+    AVX2, LbdCompBlendHMaskTest,
+    ::testing::ValuesIn({make_tuple(svt_aom_blend_a64_hmask_c,
+                                    svt_av1_blend_a64_hmask_avx2)}));
+#endif  // ARCH_X86_64
+
+#ifdef ARCH_AARCH64
+INSTANTIATE_TEST_SUITE_P(
+    NEON, LbdCompBlendHMaskTest,
+    ::testing::ValuesIn({make_tuple(svt_aom_blend_a64_hmask_c,
+                                    svt_aom_blend_a64_hmask_neon)}));
+#endif  // ARCH_AARCH64
 
 using LbdBlendA64VMaskFunc = void (*)(uint8_t *, uint32_t, const uint8_t *,
                                       uint32_t, const uint8_t *, uint32_t,
@@ -346,7 +365,6 @@ class LbdCompBlendVMaskTest
         bd_ = 8;
         func_ref_ = TEST_GET_PARAM(0);
         func_tst_ = TEST_GET_PARAM(1);
-        tst_fn_name = TEST_GET_PARAM(2);
         no_sub_ = true;
     }
 
@@ -383,13 +401,24 @@ TEST_P(LbdCompBlendVMaskTest, BlendA64Mask) {
     run_test();
 }
 
-INSTANTIATE_TEST_CASE_P(
-    BLEND, LbdCompBlendVMaskTest,
-    ::testing::ValuesIn(
-        {make_tuple(svt_aom_blend_a64_vmask_c, svt_aom_blend_a64_vmask_sse4_1,
-                    "svt_aom_blend_a64_vmask_sse4_1"),
-         make_tuple(svt_aom_blend_a64_vmask_c, svt_av1_blend_a64_vmask_avx2,
-                    "svt_dav1d_blend_a64_vmask_avx2")}));
+#ifdef ARCH_X86_64
+INSTANTIATE_TEST_SUITE_P(
+    SSE4_1, LbdCompBlendVMaskTest,
+    ::testing::ValuesIn({make_tuple(svt_aom_blend_a64_vmask_c,
+                                    svt_aom_blend_a64_vmask_sse4_1)}));
+
+INSTANTIATE_TEST_SUITE_P(
+    AVX2, LbdCompBlendVMaskTest,
+    ::testing::ValuesIn({make_tuple(svt_aom_blend_a64_vmask_c,
+                                    svt_av1_blend_a64_vmask_avx2)}));
+#endif  // ARCH_X86_64
+
+#ifdef ARCH_AARCH64
+INSTANTIATE_TEST_SUITE_P(
+    NEON, LbdCompBlendVMaskTest,
+    ::testing::ValuesIn({make_tuple(svt_aom_blend_a64_vmask_c,
+                                    svt_aom_blend_a64_vmask_neon)}));
+#endif  // ARCH_AARCH64
 
 using HbdBlendA64MaskFunc = void (*)(uint8_t *, uint32_t, const uint8_t *,
                                      uint32_t, const uint8_t *, uint32_t,
@@ -404,7 +433,6 @@ class HbdCompBlendTest
         bd_ = 8;
         func_ref_ = TEST_GET_PARAM(0);
         func_tst_ = TEST_GET_PARAM(1);
-        tst_fn_name = TEST_GET_PARAM(2);
     }
 
     void run_hbd_test(uint8_t bd) {
@@ -441,6 +469,7 @@ class HbdCompBlendTest
                   bd_);
     }
 };
+GTEST_ALLOW_UNINSTANTIATED_PARAMETERIZED_TEST(HbdCompBlendTest);
 
 TEST_P(HbdCompBlendTest, BlendA64Mask) {
     run_hbd_test(8);
@@ -448,11 +477,12 @@ TEST_P(HbdCompBlendTest, BlendA64Mask) {
     run_hbd_test(12);
 }
 
-INSTANTIATE_TEST_CASE_P(BLEND, HbdCompBlendTest,
-                        ::testing::ValuesIn({make_tuple(
-                            svt_aom_highbd_blend_a64_mask_c,
-                            svt_aom_highbd_blend_a64_mask_8bit_sse4_1,
-                            "svt_aom_highbd_blend_a64_mask_8bit_sse4_1")}));
+#ifdef ARCH_X86_64
+INSTANTIATE_TEST_SUITE_P(SSE4_1, HbdCompBlendTest,
+                         ::testing::ValuesIn({make_tuple(
+                             svt_aom_highbd_blend_a64_mask_c,
+                             svt_aom_highbd_blend_a64_mask_8bit_sse4_1)}));
+#endif  // ARCH_X86_64
 
 using HbdBlendA64D16MaskFunc = void (*)(uint8_t *, uint32_t,
                                         const CONV_BUF_TYPE *, uint32_t,
@@ -468,7 +498,6 @@ class HbdCompBlendD16Test
         bd_ = 10;
         func_ref_ = TEST_GET_PARAM(0);
         func_tst_ = TEST_GET_PARAM(1);
-        tst_fn_name = TEST_GET_PARAM(2);
     }
 
     void run_hbd_test(uint8_t bd) {
@@ -510,6 +539,7 @@ class HbdCompBlendD16Test
                   bd_);
     }
 };
+GTEST_ALLOW_UNINSTANTIATED_PARAMETERIZED_TEST(HbdCompBlendD16Test);
 
 TEST_P(HbdCompBlendD16Test, BlendA64MaskD16) {
     run_hbd_test(8);
@@ -517,15 +547,17 @@ TEST_P(HbdCompBlendD16Test, BlendA64MaskD16) {
     run_hbd_test(12);
 }
 
-INSTANTIATE_TEST_CASE_P(
-    BLEND, HbdCompBlendD16Test,
-    ::testing::ValuesIn(
-        {make_tuple(svt_aom_highbd_blend_a64_d16_mask_c,
-                    svt_aom_highbd_blend_a64_d16_mask_sse4_1,
-                    "svt_aom_highbd_blend_a64_d16_mask_sse4_1"),
-         make_tuple(svt_aom_highbd_blend_a64_d16_mask_c,
-                    svt_aom_highbd_blend_a64_d16_mask_avx2,
-                    "svt_aom_highbd_blend_a64_d16_mask_avx2")}));
+#ifdef ARCH_X86_64
+INSTANTIATE_TEST_SUITE_P(SSE4_1, HbdCompBlendD16Test,
+                         ::testing::ValuesIn({make_tuple(
+                             svt_aom_highbd_blend_a64_d16_mask_c,
+                             svt_aom_highbd_blend_a64_d16_mask_sse4_1)}));
+
+INSTANTIATE_TEST_SUITE_P(
+    AVX2, HbdCompBlendD16Test,
+    ::testing::ValuesIn({make_tuple(svt_aom_highbd_blend_a64_d16_mask_c,
+                                    svt_aom_highbd_blend_a64_d16_mask_avx2)}));
+#endif  // ARCH_X86_64
 
 using HbdBlendA64HMaskFunc = void (*)(uint8_t *, uint32_t, const uint8_t *,
                                       uint32_t, const uint8_t *, uint32_t,
@@ -539,7 +571,6 @@ class HbdCompBlendHMaskTest
         bd_ = 8;
         func_ref_ = TEST_GET_PARAM(0);
         func_tst_ = TEST_GET_PARAM(1);
-        tst_fn_name = TEST_GET_PARAM(2);
         no_sub_ = true;
     }
 
@@ -573,6 +604,7 @@ class HbdCompBlendHMaskTest
                   bd_);
     }
 };
+GTEST_ALLOW_UNINSTANTIATED_PARAMETERIZED_TEST(HbdCompBlendHMaskTest);
 
 TEST_P(HbdCompBlendHMaskTest, BlendA64Mask) {
     run_hbd_test(8);
@@ -580,11 +612,12 @@ TEST_P(HbdCompBlendHMaskTest, BlendA64Mask) {
     run_hbd_test(12);
 }
 
-INSTANTIATE_TEST_CASE_P(BLEND, HbdCompBlendHMaskTest,
-                        ::testing::ValuesIn({make_tuple(
-                            svt_aom_highbd_blend_a64_hmask_8bit_c,
-                            svt_aom_highbd_blend_a64_hmask_8bit_sse4_1,
-                            "svt_aom_highbd_blend_a64_hmask_8bit_sse4_1")}));
+#ifdef ARCH_X86_64
+INSTANTIATE_TEST_SUITE_P(SSE4_1, HbdCompBlendHMaskTest,
+                         ::testing::ValuesIn({make_tuple(
+                             svt_aom_highbd_blend_a64_hmask_8bit_c,
+                             svt_aom_highbd_blend_a64_hmask_8bit_sse4_1)}));
+#endif  // ARCH_X86_64
 
 using EbHbdBlendA64HMaskFunc = void (*)(uint16_t *, uint32_t, const uint16_t *,
                                         uint32_t, const uint16_t *, uint32_t,
@@ -598,7 +631,6 @@ class EbHbdCompBlendHMaskTest
         bd_ = 8;
         func_ref_ = TEST_GET_PARAM(0);
         func_tst_ = TEST_GET_PARAM(1);
-        tst_fn_name = TEST_GET_PARAM(2);
         no_sub_ = true;
     }
 
@@ -637,6 +669,7 @@ class EbHbdCompBlendHMaskTest
                   bd_);
     }
 };
+GTEST_ALLOW_UNINSTANTIATED_PARAMETERIZED_TEST(EbHbdCompBlendHMaskTest);
 
 TEST_P(EbHbdCompBlendHMaskTest, BlendA64Mask) {
     run_hbd_test(8);
@@ -644,15 +677,17 @@ TEST_P(EbHbdCompBlendHMaskTest, BlendA64Mask) {
     run_hbd_test(12);
 }
 
-INSTANTIATE_TEST_CASE_P(
-    BLEND, EbHbdCompBlendHMaskTest,
-    ::testing::ValuesIn(
-        {make_tuple(svt_aom_highbd_blend_a64_hmask_16bit_c,
-                    svt_aom_highbd_blend_a64_hmask_16bit_sse4_1,
-                    "svt_aom_highbd_blend_a64_hmask_16bit_sse4_1"),
-         make_tuple(svt_aom_highbd_blend_a64_hmask_16bit_c,
-                    svt_av1_highbd_blend_a64_hmask_16bit_avx2,
-                    "svt_dav1d_highbd_blend_a64_hmask_16bit_avx2")}));
+#ifdef ARCH_X86_64
+INSTANTIATE_TEST_SUITE_P(SSE4_1, EbHbdCompBlendHMaskTest,
+                         ::testing::ValuesIn({make_tuple(
+                             svt_aom_highbd_blend_a64_hmask_16bit_c,
+                             svt_aom_highbd_blend_a64_hmask_16bit_sse4_1)}));
+
+INSTANTIATE_TEST_SUITE_P(AVX2, EbHbdCompBlendHMaskTest,
+                         ::testing::ValuesIn({make_tuple(
+                             svt_aom_highbd_blend_a64_hmask_16bit_c,
+                             svt_av1_highbd_blend_a64_hmask_16bit_avx2)}));
+#endif  // ARCH_X86_64
 
 using HbdBlendA64VMaskFunc = void (*)(uint8_t *, uint32_t, const uint8_t *,
                                       uint32_t, const uint8_t *, uint32_t,
@@ -666,7 +701,6 @@ class HbdCompBlendVMaskTest
         bd_ = 8;
         func_ref_ = TEST_GET_PARAM(0);
         func_tst_ = TEST_GET_PARAM(1);
-        tst_fn_name = TEST_GET_PARAM(2);
         no_sub_ = true;
     }
 
@@ -700,6 +734,7 @@ class HbdCompBlendVMaskTest
                   bd_);
     }
 };
+GTEST_ALLOW_UNINSTANTIATED_PARAMETERIZED_TEST(HbdCompBlendVMaskTest);
 
 TEST_P(HbdCompBlendVMaskTest, BlendA64Mask) {
     run_hbd_test(8);
@@ -707,11 +742,12 @@ TEST_P(HbdCompBlendVMaskTest, BlendA64Mask) {
     run_hbd_test(12);
 }
 
-INSTANTIATE_TEST_CASE_P(BLEND, HbdCompBlendVMaskTest,
-                        ::testing::ValuesIn({make_tuple(
-                            svt_aom_highbd_blend_a64_vmask_8bit_c,
-                            svt_aom_highbd_blend_a64_vmask_8bit_sse4_1,
-                            "svt_aom_highbd_blend_a64_vmask_8bit_sse4_1")}));
+#ifdef ARCH_X86_64
+INSTANTIATE_TEST_SUITE_P(SSE4_1, HbdCompBlendVMaskTest,
+                         ::testing::ValuesIn({make_tuple(
+                             svt_aom_highbd_blend_a64_vmask_8bit_c,
+                             svt_aom_highbd_blend_a64_vmask_8bit_sse4_1)}));
+#endif  // ARCH_X86_64
 
 using EbHbdBlendA64VMaskFunc = void (*)(uint16_t *, uint32_t, const uint16_t *,
                                         uint32_t, const uint16_t *, uint32_t,
@@ -725,7 +761,6 @@ class EbHbdCompBlendVMaskTest
         bd_ = 8;
         func_ref_ = TEST_GET_PARAM(0);
         func_tst_ = TEST_GET_PARAM(1);
-        tst_fn_name = TEST_GET_PARAM(2);
         no_sub_ = true;
     }
 
@@ -764,6 +799,7 @@ class EbHbdCompBlendVMaskTest
                   bd_);
     }
 };
+GTEST_ALLOW_UNINSTANTIATED_PARAMETERIZED_TEST(EbHbdCompBlendVMaskTest);
 
 TEST_P(EbHbdCompBlendVMaskTest, BlendA64Mask) {
     run_hbd_test(8);
@@ -771,15 +807,17 @@ TEST_P(EbHbdCompBlendVMaskTest, BlendA64Mask) {
     run_hbd_test(12);
 }
 
-INSTANTIATE_TEST_CASE_P(
-    BLEND, EbHbdCompBlendVMaskTest,
-    ::testing::ValuesIn(
-        {make_tuple(svt_aom_highbd_blend_a64_vmask_16bit_c,
-                    svt_aom_highbd_blend_a64_vmask_16bit_sse4_1,
-                    "svt_aom_highbd_blend_a64_vmask_16bit_sse4_1"),
-         make_tuple(svt_aom_highbd_blend_a64_vmask_16bit_c,
-                    svt_av1_highbd_blend_a64_vmask_16bit_avx2,
-                    "svt_dav1d_highbd_blend_a64_vmask_16bit_avx2")}));
+#ifdef ARCH_X86_64
+INSTANTIATE_TEST_SUITE_P(SSE4_1, EbHbdCompBlendVMaskTest,
+                         ::testing::ValuesIn({make_tuple(
+                             svt_aom_highbd_blend_a64_vmask_16bit_c,
+                             svt_aom_highbd_blend_a64_vmask_16bit_sse4_1)}));
+
+INSTANTIATE_TEST_SUITE_P(AVX2, EbHbdCompBlendVMaskTest,
+                         ::testing::ValuesIn({make_tuple(
+                             svt_aom_highbd_blend_a64_vmask_16bit_c,
+                             svt_av1_highbd_blend_a64_vmask_16bit_avx2)}));
+#endif  // ARCH_X86_64
 
 typedef void (*BuildCompDiffwtdMaskedFunc)(uint8_t *mask,
                                            DIFFWTD_MASK_TYPE mask_type,
@@ -833,18 +871,26 @@ class BuildCompDiffwtdMaskTest
   private:
     SVTRandom rnd_;
 };
+GTEST_ALLOW_UNINSTANTIATED_PARAMETERIZED_TEST(BuildCompDiffwtdMaskTest);
 
 TEST_P(BuildCompDiffwtdMaskTest, MatchTest) {
     run_test(DIFFWTD_38);
     run_test(DIFFWTD_38_INV);
 }
 
-INSTANTIATE_TEST_CASE_P(
-    CompUtilTest, BuildCompDiffwtdMaskTest,
+#ifdef ARCH_X86_64
+INSTANTIATE_TEST_SUITE_P(
+    SSE4_1, BuildCompDiffwtdMaskTest,
     ::testing::Combine(
         ::testing::Range(BLOCK_4X4, BlockSizeS_ALL),
-        ::testing::Values(svt_av1_build_compound_diffwtd_mask_sse4_1,
-                          svt_av1_build_compound_diffwtd_mask_avx2)));
+        ::testing::Values(svt_av1_build_compound_diffwtd_mask_sse4_1)));
+
+INSTANTIATE_TEST_SUITE_P(
+    AVX2, BuildCompDiffwtdMaskTest,
+    ::testing::Combine(
+        ::testing::Range(BLOCK_4X4, BlockSizeS_ALL),
+        ::testing::Values(svt_av1_build_compound_diffwtd_mask_avx2)));
+#endif  // ARCH_X86_64
 
 typedef void (*BuildCompDiffwtdMaskedHighbdFunc)(
     uint8_t *mask, DIFFWTD_MASK_TYPE mask_type, const uint8_t *src0,
@@ -912,6 +958,7 @@ class BuildCompDiffwtdMaskHighbdTest
   private:
     SVTRandom rnd_;
 };
+GTEST_ALLOW_UNINSTANTIATED_PARAMETERIZED_TEST(BuildCompDiffwtdMaskHighbdTest);
 
 TEST_P(BuildCompDiffwtdMaskHighbdTest, MatchTest) {
     run_test(DIFFWTD_38, 8);
@@ -922,12 +969,19 @@ TEST_P(BuildCompDiffwtdMaskHighbdTest, MatchTest) {
     run_test(DIFFWTD_38_INV, 12);
 }
 
-INSTANTIATE_TEST_CASE_P(
-    CompUtilTest, BuildCompDiffwtdMaskHighbdTest,
+#ifdef ARCH_X86_64
+INSTANTIATE_TEST_SUITE_P(
+    SSSE3, BuildCompDiffwtdMaskHighbdTest,
     ::testing::Combine(
         ::testing::Range(BLOCK_4X4, BlockSizeS_ALL),
-        ::testing::Values(svt_av1_build_compound_diffwtd_mask_highbd_ssse3,
-                          svt_av1_build_compound_diffwtd_mask_highbd_avx2)));
+        ::testing::Values(svt_av1_build_compound_diffwtd_mask_highbd_ssse3)));
+
+INSTANTIATE_TEST_SUITE_P(
+    AVX2, BuildCompDiffwtdMaskHighbdTest,
+    ::testing::Combine(
+        ::testing::Range(BLOCK_4X4, BlockSizeS_ALL),
+        ::testing::Values(svt_av1_build_compound_diffwtd_mask_highbd_avx2)));
+#endif  // ARCH_X86_64
 
 // test svt_av1_build_compound_diffwtd_mask_d16_avx2
 typedef void (*BuildCompDiffwtdMaskD16Func)(
@@ -1013,19 +1067,28 @@ class BuildCompDiffwtdMaskD16Test
     }
     SVTRandom rnd_;
 };  // class BuildCompDiffwtdMaskD16Test
+GTEST_ALLOW_UNINSTANTIATED_PARAMETERIZED_TEST(BuildCompDiffwtdMaskD16Test);
 
 TEST_P(BuildCompDiffwtdMaskD16Test, MatchTest) {
     run_test();
 }
 
-INSTANTIATE_TEST_CASE_P(
+#ifdef ARCH_X86_64
+INSTANTIATE_TEST_SUITE_P(
     SSE4_1, BuildCompDiffwtdMaskD16Test,
     ::testing::Combine(
         ::testing::Range(8, 13, 2),
-        ::testing::Values(svt_av1_build_compound_diffwtd_mask_d16_sse4_1,
-                          svt_av1_build_compound_diffwtd_mask_d16_avx2),
+        ::testing::Values(svt_av1_build_compound_diffwtd_mask_d16_sse4_1),
         ::testing::Range(BLOCK_4X4, BlockSizeS_ALL)));
 
+INSTANTIATE_TEST_SUITE_P(
+    AVX2, BuildCompDiffwtdMaskD16Test,
+    ::testing::Combine(
+        ::testing::Range(8, 13, 2),
+        ::testing::Values(svt_av1_build_compound_diffwtd_mask_d16_avx2),
+        ::testing::Range(BLOCK_4X4, BlockSizeS_ALL)));
+#endif  // ARCH_X86_64
+
 typedef int64_t (*AomSseFunc)(const uint8_t *, int, const uint8_t *, int, int,
                               int);
 typedef ::testing::tuple<BlockSize, AomSseFunc> AomSseParam;
@@ -1072,10 +1135,19 @@ TEST_P(AomSseTest, MatchTest) {
     run_test();
 }
 
-INSTANTIATE_TEST_CASE_P(
-    SSETEST, AomSseTest,
+#ifdef ARCH_X86_64
+INSTANTIATE_TEST_SUITE_P(
+    AVX2, AomSseTest,
     ::testing::Combine(::testing::Range(BLOCK_4X4, BlockSizeS_ALL),
                        ::testing::Values(svt_aom_sse_avx2)));
+#endif  // ARCH_X86_64
+
+#ifdef ARCH_AARCH64
+INSTANTIATE_TEST_SUITE_P(
+    NEON, AomSseTest,
+    ::testing::Combine(::testing::Range(BLOCK_4X4, BlockSizeS_ALL),
+                       ::testing::Values(svt_aom_sse_neon)));
+#endif  // ARCH_AARCH64
 
 class AomSseHighbdTest : public ::testing::TestWithParam<AomSseParam> {
   public:
@@ -1125,40 +1197,47 @@ class AomSseHighbdTest : public ::testing::TestWithParam<AomSseParam> {
             int64_t res_tst = test_impl(
                 (uint8_t *)a_, width, (uint8_t *)b_, width, height, width);
 
-            ASSERT_EQ(res_ref, res_tst);
+            ASSERT_EQ(res_ref, res_tst)
+                << "Mismatch: ref = " << res_ref << ", test = " << res_tst
+                << ", width = " << width << ", height = " << height << "\n";
         }
     }
 
   private:
     SVTRandom rnd_;
 };
+GTEST_ALLOW_UNINSTANTIATED_PARAMETERIZED_TEST(AomSseHighbdTest);
 
 TEST_P(AomSseHighbdTest, MatchTest) {
     run_test();
 }
 
-INSTANTIATE_TEST_CASE_P(
-    SSETEST, AomSseHighbdTest,
-    ::testing::Combine(::testing::Range(BLOCK_4X4, BlockSizeS_ALL),
-                       ::testing::Values(svt_aom_highbd_sse_avx2)));
-
-INSTANTIATE_TEST_CASE_P(
-    SSETEST_unusula_sizes, AomSseHighbdTest,
-    ::testing::Combine(::testing::Range(BlockSizeS_ALL,
+#ifdef ARCH_X86_64
+INSTANTIATE_TEST_SUITE_P(
+    AVX2, AomSseHighbdTest,
+    ::testing::Combine(::testing::Range(BLOCK_4X4,
                                         (BlockSize)(BlockSizeS_ALL + 2)),
                        ::testing::Values(svt_aom_highbd_sse_avx2)));
+#endif  // ARCH_X86_64
 
-typedef void (*AomSubstractBlockFunc)(int, int, int16_t *, ptrdiff_t,
-                                      const uint8_t *, ptrdiff_t,
-                                      const uint8_t *, ptrdiff_t);
-typedef ::testing::tuple<BlockSize, AomSubstractBlockFunc>
-    AomSubstractBlockParam;
+#ifdef ARCH_AARCH64
+INSTANTIATE_TEST_SUITE_P(
+    NEON, AomSseHighbdTest,
+    ::testing::Combine(::testing::Range(BLOCK_4X4,
+                                        (BlockSize)(BlockSizeS_ALL + 2)),
+                       ::testing::Values(svt_aom_highbd_sse_neon)));
+#endif  // ARCH_AARCH64
 
-class AomSubstractBlockTest
-    : public ::testing::TestWithParam<AomSubstractBlockParam> {
+typedef void (*AomSubtractBlockFunc)(int, int, int16_t *, ptrdiff_t,
+                                     const uint8_t *, ptrdiff_t,
+                                     const uint8_t *, ptrdiff_t);
+typedef ::testing::tuple<BlockSize, AomSubtractBlockFunc> AomSubtractBlockParam;
+
+class AomSubtractBlockTest
+    : public ::testing::TestWithParam<AomSubtractBlockParam> {
   public:
-    AomSubstractBlockTest() : rnd_(0, 255){};
-    virtual ~AomSubstractBlockTest() {
+    AomSubtractBlockTest() : rnd_(0, 255){};
+    virtual ~AomSubtractBlockTest() {
     }
 
     void TearDown() override {
@@ -1167,7 +1246,7 @@ class AomSubstractBlockTest
 
     void run_test() {
         const int block_size = TEST_GET_PARAM(0);
-        AomSubstractBlockFunc test_impl = TEST_GET_PARAM(1);
+        AomSubtractBlockFunc test_impl = TEST_GET_PARAM(1);
         const int width = block_size_wide[block_size];
         const int height = block_size_high[block_size];
         DECLARE_ALIGNED(16, int16_t, diff_ref_[MAX_SB_SQUARE]);
@@ -1198,27 +1277,40 @@ class AomSubstractBlockTest
     SVTRandom rnd_;
 };
 
-TEST_P(AomSubstractBlockTest, MatchTest) {
+TEST_P(AomSubtractBlockTest, MatchTest) {
     run_test();
 }
 
-INSTANTIATE_TEST_CASE_P(
-    SUBSTRACT_BLOCK_TEST, AomSubstractBlockTest,
+#ifdef ARCH_X86_64
+INSTANTIATE_TEST_SUITE_P(
+    SSE2, AomSubtractBlockTest,
     ::testing::Combine(::testing::Range(BLOCK_4X4, BlockSizeS_ALL),
-                       ::testing::Values(svt_aom_subtract_block_sse2,
-                                         svt_aom_subtract_block_avx2)));
+                       ::testing::Values(svt_aom_subtract_block_sse2)));
 
-typedef void (*AomHighbdSubstractBlockFunc)(int, int, int16_t *, ptrdiff_t,
-                                            const uint8_t *, ptrdiff_t,
-                                            const uint8_t *, ptrdiff_t, int);
-typedef ::testing::tuple<BlockSize, AomHighbdSubstractBlockFunc>
-    AomHighbdSubstractBlockParam;
+INSTANTIATE_TEST_SUITE_P(
+    AVX2, AomSubtractBlockTest,
+    ::testing::Combine(::testing::Range(BLOCK_4X4, BlockSizeS_ALL),
+                       ::testing::Values(svt_aom_subtract_block_avx2)));
+#endif  // ARCH_X86_64
 
-class AomHighbdSubstractBlockTest
-    : public ::testing::TestWithParam<AomHighbdSubstractBlockParam> {
+#ifdef ARCH_AARCH64
+INSTANTIATE_TEST_SUITE_P(
+    NEON, AomSubtractBlockTest,
+    ::testing::Combine(::testing::Range(BLOCK_4X4, BlockSizeS_ALL),
+                       ::testing::Values(svt_aom_subtract_block_neon)));
+#endif  // ARCH_AARCH64
+
+typedef void (*AomHighbdSubtractBlockFunc)(int, int, int16_t *, ptrdiff_t,
+                                           const uint8_t *, ptrdiff_t,
+                                           const uint8_t *, ptrdiff_t, int);
+typedef ::testing::tuple<BlockSize, AomHighbdSubtractBlockFunc>
+    AomHighbdSubtractBlockParam;
+
+class AomHighbdSubtractBlockTest
+    : public ::testing::TestWithParam<AomHighbdSubtractBlockParam> {
   public:
-    AomHighbdSubstractBlockTest() : rnd_(0, 255){};
-    virtual ~AomHighbdSubstractBlockTest() {
+    AomHighbdSubtractBlockTest() : rnd_(0, 255){};
+    virtual ~AomHighbdSubtractBlockTest() {
     }
 
     void TearDown() override {
@@ -1227,7 +1319,7 @@ class AomHighbdSubstractBlockTest
 
     void run_test() {
         const int block_size = TEST_GET_PARAM(0);
-        AomHighbdSubstractBlockFunc test_impl = TEST_GET_PARAM(1);
+        AomHighbdSubtractBlockFunc test_impl = TEST_GET_PARAM(1);
         const int width = block_size_wide[block_size];
         const int height = block_size_high[block_size];
         DECLARE_ALIGNED(16, int16_t, diff_ref_[MAX_SB_SQUARE]);
@@ -1271,14 +1363,17 @@ class AomHighbdSubstractBlockTest
   private:
     SVTRandom rnd_;
 };
+GTEST_ALLOW_UNINSTANTIATED_PARAMETERIZED_TEST(AomHighbdSubtractBlockTest);
 
-TEST_P(AomHighbdSubstractBlockTest, MatchTest) {
+TEST_P(AomHighbdSubtractBlockTest, MatchTest) {
     run_test();
 }
 
-INSTANTIATE_TEST_CASE_P(
-    SUBSTRACT_BLOCK_TEST, AomHighbdSubstractBlockTest,
+#ifdef ARCH_X86_64
+INSTANTIATE_TEST_SUITE_P(
+    SSE2, AomHighbdSubtractBlockTest,
     ::testing::Combine(::testing::Range(BLOCK_4X4, BlockSizeS_ALL),
                        ::testing::Values(svt_aom_highbd_subtract_block_sse2)));
+#endif  // ARCH_X86_64
 
 }  // namespace
