@@ -21,21 +21,13 @@
  *
  ******************************************************************************/
 #include "gtest/gtest.h"
-// workaround to eliminate the compiling warning on linux
-// The macro will conflict with definition in gtest.h
-#ifdef __USE_GNU
-#undef __USE_GNU  // defined in EbThreads.h
-#endif
-#ifdef _GNU_SOURCE
-#undef _GNU_SOURCE  // defined in EbThreads.h
-#endif
 #include "aom_dsp_rtcd.h"
 #include "random.h"
 #include "util.h"
-#include "EbUtility.h"
+#include "utility.h"
 #include "filter.h"
 
-#include "EbEncInterPrediction.h"
+#include "enc_inter_prediction.h"
 
 using std::tuple;
 using svt_av1_test_tool::SVTRandom;  // to generate the random
@@ -105,26 +97,39 @@ TEST_P(OBMCVarianceTest, RunCheckOutput) {
     run_test(1000);
 };
 
-#define OBMC_VAR_FUNC_C(W, H) svt_aom_obmc_variance##W##x##H##_c
-#define OBMC_VAR_FUNC_SSE4_1(W, H) svt_aom_obmc_variance##W##x##H##_sse4_1
-#define OBMC_VAR_FUNC_AVX2(W, H) svt_aom_obmc_variance##W##x##H##_avx2
-#define GEN_OBMC_VAR_TEST_PARAM(W, H)                              \
-    ObmcVarParam(OBMC_VAR_FUNC_C(W, H), OBMC_VAR_FUNC_AVX2(W, H)), \
-        ObmcVarParam(OBMC_VAR_FUNC_C(W, H), OBMC_VAR_FUNC_SSE4_1(W, H))
-#define GEN_TEST_PARAMS(GEN_PARAM)                                          \
-    GEN_PARAM(128, 128), GEN_PARAM(128, 64), GEN_PARAM(64, 128),            \
-        GEN_PARAM(64, 64), GEN_PARAM(64, 32), GEN_PARAM(32, 64),            \
-        GEN_PARAM(32, 32), GEN_PARAM(32, 16), GEN_PARAM(16, 32),            \
-        GEN_PARAM(16, 16), GEN_PARAM(16, 8), GEN_PARAM(8, 16),              \
-        GEN_PARAM(8, 8), GEN_PARAM(8, 4), GEN_PARAM(4, 8), GEN_PARAM(4, 4), \
-        GEN_PARAM(4, 16), GEN_PARAM(16, 4), GEN_PARAM(8, 32),               \
-        GEN_PARAM(32, 8), GEN_PARAM(16, 64), GEN_PARAM(64, 16)
+#define OBMC_VAR_FUNC(W, H, opt) svt_aom_obmc_variance##W##x##H##_##opt
+#define GEN_OBMC_VAR_TEST_PARAM(W, H, opt) \
+    ObmcVarParam(OBMC_VAR_FUNC(W, H, c), OBMC_VAR_FUNC(W, H, opt))
+#define GEN_TEST_PARAMS(GEN_PARAM, opt)                                       \
+    {                                                                         \
+        GEN_PARAM(128, 128, opt), GEN_PARAM(128, 64, opt),                    \
+            GEN_PARAM(64, 128, opt), GEN_PARAM(64, 64, opt),                  \
+            GEN_PARAM(64, 32, opt), GEN_PARAM(32, 64, opt),                   \
+            GEN_PARAM(32, 32, opt), GEN_PARAM(32, 16, opt),                   \
+            GEN_PARAM(16, 32, opt), GEN_PARAM(16, 16, opt),                   \
+            GEN_PARAM(16, 8, opt), GEN_PARAM(8, 16, opt),                     \
+            GEN_PARAM(8, 8, opt), GEN_PARAM(8, 4, opt), GEN_PARAM(4, 8, opt), \
+            GEN_PARAM(4, 4, opt), GEN_PARAM(4, 16, opt),                      \
+            GEN_PARAM(16, 4, opt), GEN_PARAM(8, 32, opt),                     \
+            GEN_PARAM(32, 8, opt), GEN_PARAM(16, 64, opt),                    \
+            GEN_PARAM(64, 16, opt)                                            \
+    }
 
-static const ObmcVarParam obmc_var_test_params[] = {
-    GEN_TEST_PARAMS(GEN_OBMC_VAR_TEST_PARAM)};
+#ifdef ARCH_X86_64
+INSTANTIATE_TEST_SUITE_P(
+    SSE4_1, OBMCVarianceTest,
+    ::testing::ValuesIn(GEN_TEST_PARAMS(GEN_OBMC_VAR_TEST_PARAM, sse4_1)));
 
-INSTANTIATE_TEST_CASE_P(OBMC, OBMCVarianceTest,
-                        ::testing::ValuesIn(obmc_var_test_params));
+INSTANTIATE_TEST_SUITE_P(
+    AVX2, OBMCVarianceTest,
+    ::testing::ValuesIn(GEN_TEST_PARAMS(GEN_OBMC_VAR_TEST_PARAM, avx2)));
+#endif  // ARCH_x86_64
+
+#ifdef ARCH_AARCH64
+INSTANTIATE_TEST_SUITE_P(
+    NEON, OBMCVarianceTest,
+    ::testing::ValuesIn(GEN_TEST_PARAMS(GEN_OBMC_VAR_TEST_PARAM, neon)));
+#endif  // ARCH_AARCH64
 
 using ObmcSubPixVarFunc = unsigned int (*)(const uint8_t *pre, int pre_stride,
                                            int xoffset, int yoffset,
@@ -209,19 +214,23 @@ TEST_P(OBMCSubPixelVarianceTest, RunCheckOutput) {
     run_test(1000);
 };
 
-#define OBMC_SUB_PIX_VAR_FUNC_C(W, H) \
-    svt_aom_obmc_sub_pixel_variance##W##x##H##_c
-#define OBMC_SUB_PIX_VAR_FUNC_SSE41(W, H) \
-    svt_aom_obmc_sub_pixel_variance##W##x##H##_sse4_1
-#define GEN_OBMC_SUB_PIX_VAR_TEST_PARAM(W, H)         \
-    ObmcSubPixVarParam(OBMC_SUB_PIX_VAR_FUNC_C(W, H), \
-                       OBMC_SUB_PIX_VAR_FUNC_SSE41(W, H))
+#define OBMC_SUB_PIX_VAR_FUNC(W, H, opt) \
+    svt_aom_obmc_sub_pixel_variance##W##x##H##_##opt
+#define GEN_OBMC_SUB_PIX_VAR_TEST_PARAM(W, H, opt)     \
+    ObmcSubPixVarParam(OBMC_SUB_PIX_VAR_FUNC(W, H, c), \
+                       OBMC_SUB_PIX_VAR_FUNC(W, H, opt))
 
-static const ObmcSubPixVarParam obmc_sub_pix_var_test_params[] = {
-    GEN_TEST_PARAMS(GEN_OBMC_SUB_PIX_VAR_TEST_PARAM)};
+#ifdef ARCH_X86_64
+INSTANTIATE_TEST_SUITE_P(SSE4_1, OBMCSubPixelVarianceTest,
+                         ::testing::ValuesIn(GEN_TEST_PARAMS(
+                             GEN_OBMC_SUB_PIX_VAR_TEST_PARAM, sse4_1)));
+#endif  // ARCH_X86_64
 
-INSTANTIATE_TEST_CASE_P(OBMC, OBMCSubPixelVarianceTest,
-                        ::testing::ValuesIn(obmc_sub_pix_var_test_params));
+#ifdef ARCH_AARCH64
+INSTANTIATE_TEST_SUITE_P(NEON, OBMCSubPixelVarianceTest,
+                         ::testing::ValuesIn(GEN_TEST_PARAMS(
+                             GEN_OBMC_SUB_PIX_VAR_TEST_PARAM, neon)));
+#endif  // ARCH_AARCH64
 
 using CalcTargetWeightedPredFn = void (*)(uint8_t, MacroBlockD *, int, uint8_t,
                                           MbModeInfo *, void *, const int);
@@ -349,21 +358,24 @@ class CalcTargetWeightedPredTest
     uint8_t *tmp_tst;
     int stride;
 };
+GTEST_ALLOW_UNINSTANTIATED_PARAMETERIZED_TEST(CalcTargetWeightedPredTest);
 
 TEST_P(CalcTargetWeightedPredTest, RunCheckOutput) {
     run_test();
 };
 
-INSTANTIATE_TEST_CASE_P(CalcTargetWeightedPredTestAbove,
-                        CalcTargetWeightedPredTest,
-                        ::testing::Values(::testing::make_tuple(
-                            &svt_av1_calc_target_weighted_pred_above_c,
-                            &svt_av1_calc_target_weighted_pred_above_avx2)));
+#ifdef ARCH_X86_64
+INSTANTIATE_TEST_SUITE_P(CalcTargetWeightedPredTestAbove,
+                         CalcTargetWeightedPredTest,
+                         ::testing::Values(::testing::make_tuple(
+                             &svt_av1_calc_target_weighted_pred_above_c,
+                             &svt_av1_calc_target_weighted_pred_above_avx2)));
 
-INSTANTIATE_TEST_CASE_P(CalcTargetWeightedPredTestLeft,
-                        CalcTargetWeightedPredTest,
-                        ::testing::Values(::testing::make_tuple(
-                            &svt_av1_calc_target_weighted_pred_left_c,
-                            &svt_av1_calc_target_weighted_pred_left_avx2)));
+INSTANTIATE_TEST_SUITE_P(CalcTargetWeightedPredTestLeft,
+                         CalcTargetWeightedPredTest,
+                         ::testing::Values(::testing::make_tuple(
+                             &svt_av1_calc_target_weighted_pred_left_c,
+                             &svt_av1_calc_target_weighted_pred_left_avx2)));
+#endif  // ARCH_X86_64
 
 }  // namespace
