@@ -1,13 +1,14 @@
 /*
-* Copyright(c) 2019 Netflix, Inc.
-*
-* This source code is subject to the terms of the BSD 2 Clause License and
-* the Alliance for Open Media Patent License 1.0. If the BSD 2 Clause License
-* was not distributed with this source code in the LICENSE file, you can
-* obtain it at https://www.aomedia.org/license/software-license. If the Alliance for Open
-* Media Patent License 1.0 was not distributed with this source code in the
-* PATENTS file, you can obtain it at https://www.aomedia.org/license/patent-license.
-*/
+ * Copyright(c) 2019 Netflix, Inc.
+ *
+ * This source code is subject to the terms of the BSD 2 Clause License and
+ * the Alliance for Open Media Patent License 1.0. If the BSD 2 Clause License
+ * was not distributed with this source code in the LICENSE file, you can
+ * obtain it at https://www.aomedia.org/license/software-license. If the
+ * Alliance for Open Media Patent License 1.0 was not distributed with this
+ * source code in the PATENTS file, you can obtain it at
+ * https://www.aomedia.org/license/patent-license.
+ */
 
 /******************************************************************************
  * @file PaletteModeUtilTest.cc
@@ -21,21 +22,15 @@
  * @author Cidana-Edmond
  *
  ******************************************************************************/
+#include <algorithm>
 #include <vector>
+
 #include "gtest/gtest.h"
-// workaround to eliminate the compiling warning on linux
-// The macro will conflict with definition in gtest.h
-#ifdef __USE_GNU
-#undef __USE_GNU  // defined in EbThreads.h
-#endif
-#ifdef _GNU_SOURCE
-#undef _GNU_SOURCE  // defined in EbThreads.h
-#endif
-#include "EbDefinitions.h"
-#include "EbUtility.h"
+#include "definitions.h"
+#include "utility.h"
 #include "random.h"
 #include "util.h"
-#include "EbTime.h"
+#include "svt_time.h"
 #include "aom_dsp_rtcd.h"
 
 using std::tuple;
@@ -47,7 +42,8 @@ namespace {
 extern "C" int svt_av1_count_colors(const uint8_t *src, int stride, int rows,
                                     int cols, int *val_count);
 extern "C" int svt_av1_count_colors_highbd(uint16_t *src, int stride, int rows,
-                                           int cols, int bit_depth, int *val_count);
+                                           int cols, int bit_depth,
+                                           int *val_count);
 
 /**
  * @brief Unit test for counting colors:
@@ -165,9 +161,11 @@ TEST_F(ColorCountHbdTest, MatchTest12Bit) {
 }
 
 extern "C" void svt_av1_k_means_dim1_c(const int *data, int *centroids,
-                                 uint8_t *indices, int n, int k, int max_itr);
+                                       uint8_t *indices, int n, int k,
+                                       int max_itr);
 extern "C" void svt_av1_k_means_dim2_c(const int *data, int *centroids,
-                                 uint8_t *indices, int n, int k, int max_itr);
+                                       uint8_t *indices, int n, int k,
+                                       int max_itr);
 static const int MaxItr = 50;
 /**
  * @brief Unit test for kmeans functions:
@@ -316,12 +314,11 @@ TEST_P(KMeansTest, CheckOutput2D) {
     run_test_2d(1000);
 };
 
-INSTANTIATE_TEST_CASE_P(PalleteMode, KMeansTest,
-                        ::testing::Range(PALETTE_MIN_SIZE, PALETTE_MAX_SIZE));
-
+INSTANTIATE_TEST_SUITE_P(PalleteMode, KMeansTest,
+                         ::testing::Range(PALETTE_MIN_SIZE, PALETTE_MAX_SIZE));
 
 typedef void (*av1_k_means_func)(const int *data, int *centroids,
-                      uint8_t *indices, int n, int k, int max_itr);
+                                 uint8_t *indices, int n, int k, int max_itr);
 
 #define MAX_BLOCK_SIZE (MAX_SB_SIZE * MAX_SB_SIZE)
 typedef std::tuple<int, int> BlockSize;
@@ -344,42 +341,41 @@ BlockSize TEST_BLOCK_SIZES[] = {BlockSize(4, 4),
 TestPattern TEST_PATTERNS[] = {MIN, MAX, RANDOM};
 
 static void svt_av1_calc_indices_dim1_c_wrap(const int *data, int *centroids,
-                                    uint8_t *indices, int n, int k,
-                                    int max_itr)
-{
+                                             uint8_t *indices, int n, int k,
+                                             int max_itr) {
     (void)max_itr;
     svt_av1_calc_indices_dim1_c(data, centroids, indices, n, k);
 }
 
 static void svt_av1_calc_indices_dim1_avx2_wrap(const int *data, int *centroids,
-                                    uint8_t *indices, int n, int k,
-                                    int max_itr)
-{
+                                                uint8_t *indices, int n, int k,
+                                                int max_itr) {
     (void)max_itr;
     svt_av1_calc_indices_dim1_avx2(data, centroids, indices, n, k);
 }
 
 static void svt_av1_calc_indices_dim2_c_wrap(const int *data, int *centroids,
-                                         uint8_t *indices, int n, int k,
-                                         int max_itr) {
+                                             uint8_t *indices, int n, int k,
+                                             int max_itr) {
     (void)max_itr;
     svt_av1_calc_indices_dim2_c(data, centroids, indices, n, k);
 }
 
 static void svt_av1_calc_indices_dim2_avx2_wrap(const int *data, int *centroids,
-                                            uint8_t *indices, int n, int k,
-                                            int max_itr) {
+                                                uint8_t *indices, int n, int k,
+                                                int max_itr) {
     (void)max_itr;
     svt_av1_calc_indices_dim2_avx2(data, centroids, indices, n, k);
 }
 
 typedef std::tuple<av1_k_means_func, av1_k_means_func> FuncPair;
 FuncPair TEST_FUNC_PAIRS[] = {
-    FuncPair(svt_av1_calc_indices_dim1_c_wrap, svt_av1_calc_indices_dim1_avx2_wrap),
+    FuncPair(svt_av1_calc_indices_dim1_c_wrap,
+             svt_av1_calc_indices_dim1_avx2_wrap),
     FuncPair(svt_av1_k_means_dim1_c, svt_av1_k_means_dim1_avx2),
-    FuncPair(svt_av1_calc_indices_dim2_c_wrap, svt_av1_calc_indices_dim2_avx2_wrap),
-    FuncPair(svt_av1_k_means_dim2_c, svt_av1_k_means_dim2_avx2)
-};
+    FuncPair(svt_av1_calc_indices_dim2_c_wrap,
+             svt_av1_calc_indices_dim2_avx2_wrap),
+    FuncPair(svt_av1_k_means_dim2_c, svt_av1_k_means_dim2_avx2)};
 
 typedef std::tuple<TestPattern, BlockSize, FuncPair> Av1KMeansDimParam;
 
@@ -541,7 +537,7 @@ TEST_P(Av1KMeansDim, DISABLED_speed) {
     speed();
 };
 
-INSTANTIATE_TEST_CASE_P(
+INSTANTIATE_TEST_SUITE_P(
     Av1KMeansDim, Av1KMeansDim,
     ::testing::Combine(::testing::ValuesIn(TEST_PATTERNS),
                        ::testing::ValuesIn(TEST_BLOCK_SIZES),
