@@ -25,10 +25,10 @@
 
 #include "gtest/gtest.h"
 #include "aom_dsp_rtcd.h"
-#include "EbDefinitions.h"
-#include "EbUtility.h"
-#include "EbRestoration.h"
-#include "EbUnitTestUtility.h"
+#include "definitions.h"
+#include "utility.h"
+#include "restoration.h"
+#include "unit_test_utility.h"
 #include "random.h"
 #include "util.h"
 
@@ -329,19 +329,31 @@ TEST_P(PixelProjErrorLbdTest, DISABLED_SpeedTest) {
     run_speed_test(256, 0, 0);
 }
 
-static const PixelProjErrorTestParam lbd_test_vector[] = {
-    make_tuple(svt_av1_lowbd_pixel_proj_error_sse4_1,
-               svt_av1_lowbd_pixel_proj_error_c),
-    make_tuple(svt_av1_lowbd_pixel_proj_error_avx2,
-               svt_av1_lowbd_pixel_proj_error_c),
-#if EN_AVX512_SUPPORT
-    make_tuple(svt_av1_lowbd_pixel_proj_error_avx512,
-               svt_av1_lowbd_pixel_proj_error_c)
-#endif
-};
+#if ARCH_X86_64
+INSTANTIATE_TEST_SUITE_P(
+    SSE4_1, PixelProjErrorLbdTest,
+    ::testing::Values(make_tuple(svt_av1_lowbd_pixel_proj_error_sse4_1,
+                                 svt_av1_lowbd_pixel_proj_error_c)));
 
-INSTANTIATE_TEST_CASE_P(RST, PixelProjErrorLbdTest,
-                        ::testing::ValuesIn(lbd_test_vector));
+INSTANTIATE_TEST_SUITE_P(
+    AVX2, PixelProjErrorLbdTest,
+    ::testing::Values(make_tuple(svt_av1_lowbd_pixel_proj_error_avx2,
+                                 svt_av1_lowbd_pixel_proj_error_c)));
+
+#if EN_AVX512_SUPPORT
+INSTANTIATE_TEST_SUITE_P(
+    AVX512, PixelProjErrorLbdTest,
+    ::testing::Values(make_tuple(svt_av1_lowbd_pixel_proj_error_avx512,
+                                 svt_av1_lowbd_pixel_proj_error_c)));
+#endif
+#endif  // ARCH_X86_64
+
+#if ARCH_AARCH64
+INSTANTIATE_TEST_SUITE_P(
+    NEON, PixelProjErrorLbdTest,
+    ::testing::Values(make_tuple(svt_av1_lowbd_pixel_proj_error_neon,
+                                 svt_av1_lowbd_pixel_proj_error_c)));
+#endif  // ARCH_AARCH64
 
 class PixelProjErrorHbdTest : public PixelProjErrorTest<uint16_t> {
   protected:
@@ -369,6 +381,7 @@ class PixelProjErrorHbdTest : public PixelProjErrorTest<uint16_t> {
   private:
     SVTRandom rnd12_;
 };
+GTEST_ALLOW_UNINSTANTIATED_PARAMETERIZED_TEST(PixelProjErrorHbdTest);
 
 TEST_P(PixelProjErrorHbdTest, MatchTestWithRandomValue) {
     run_random_test(50, true);
@@ -380,14 +393,16 @@ TEST_P(PixelProjErrorHbdTest, MatchTestWithExtremeValue) {
     run_extreme_test();
 }
 
-static const PixelProjErrorTestParam hbd_test_vector[] = {
-    make_tuple(svt_av1_highbd_pixel_proj_error_sse4_1,
-               svt_av1_highbd_pixel_proj_error_c),
-    make_tuple(svt_av1_highbd_pixel_proj_error_avx2,
-               svt_av1_highbd_pixel_proj_error_c)};
+#if ARCH_X86_64
+INSTANTIATE_TEST_SUITE_P(
+    SSE4_1, PixelProjErrorHbdTest,
+    ::testing::Values(make_tuple(svt_av1_highbd_pixel_proj_error_sse4_1,
+                                 svt_av1_highbd_pixel_proj_error_c)));
 
-INSTANTIATE_TEST_CASE_P(RST, PixelProjErrorHbdTest,
-                        ::testing::ValuesIn(hbd_test_vector));
+INSTANTIATE_TEST_SUITE_P(
+    AVX2, PixelProjErrorHbdTest,
+    ::testing::Values(make_tuple(svt_av1_highbd_pixel_proj_error_avx2,
+                                 svt_av1_highbd_pixel_proj_error_c)));
 
 // test svt_get_proj_subspace
 TEST(SelfGuidedToolsTest, GetProjSubspaceMatchTest) {
@@ -462,7 +477,7 @@ TEST(SelfGuidedToolsTest, GetProjSubspaceMatchTest) {
             aom_clear_system_state();
             int32_t xqd_c[2] = {0};
             int32_t xqd_asm[2] = {0};
-            const SgrParamsType *const params = &eb_sgr_params[ep];
+            const SgrParamsType *const params = &svt_aom_eb_sgr_params[ep];
             svt_get_proj_subspace_c(input,
                                     width,
                                     height,
@@ -576,7 +591,7 @@ TEST(SelfGuidedToolsTest, GetProjSubspaceMatchTestHbd) {
             aom_clear_system_state();
             int32_t xqd_c[2] = {0};
             int32_t xqd_asm[2] = {0};
-            const SgrParamsType *const params = &eb_sgr_params[ep];
+            const SgrParamsType *const params = &svt_aom_eb_sgr_params[ep];
             svt_get_proj_subspace_c(CONVERT_TO_BYTEPTR(input),
                                     width,
                                     height,
@@ -617,5 +632,6 @@ TEST(SelfGuidedToolsTest, GetProjSubspaceMatchTestHbd) {
     svt_aom_free(output_);
     svt_aom_free(tmpbuf);
 }
+#endif  // ARCH_X86_64
 
 }  // namespace
