@@ -18,13 +18,14 @@
  * @author Cidana-Edmond Cidana-Ryan Cidana-Wenyao
  *
  ******************************************************************************/
+#include <algorithm>
 
 #include "EbSvtAv1Enc.h"
 #include "Y4mVideoSource.h"
 #include "YuvVideoSource.h"
 #include "DummyVideoSource.h"
 #include "gtest/gtest.h"
-#include "EbDefinitions.h"
+#include "definitions.h"
 #include "RefDecoder.h"
 #include "SvtAv1E2EFramework.h"
 #include "CompareTools.h"
@@ -504,7 +505,7 @@ void SvtAv1E2ETestFramework::run_encode_process() {
             // try to get one encoded frame, flush the encoder
             // if src_file_eos is true
             do {
-                // non-blocking call
+                // non-blocking call if not using low-delay
                 EbBufferHeaderType *enc_out = nullptr;
                 {
                     TimeAutoCount counter(ENCODING, collect_);
@@ -518,6 +519,16 @@ void SvtAv1E2ETestFramework::run_encode_process() {
 
                 // process the output buffer
                 if (return_error != EB_NoErrorEmptyQueue && enc_out) {
+#if OPT_LD_LATENCY2
+                    if (enc_out->flags & EB_BUFFERFLAG_EOS) {
+                        enc_file_eos = true;
+                        printf("Encoder EOS\n");
+                    } else {
+                        // send to reference decoder
+                        TimeAutoCount counter(CONFORMANCE, collect_);
+                        process_compress_data(enc_out);
+                    }
+#else
                     // send to reference decoder
                     TimeAutoCount counter(CONFORMANCE, collect_);
                     process_compress_data(enc_out);
@@ -525,6 +536,7 @@ void SvtAv1E2ETestFramework::run_encode_process() {
                         enc_file_eos = true;
                         printf("Encoder EOS\n");
                     }
+#endif
                     // check if the process has encounter error, break out if
                     // true, like the recon frame does not match with decoded
                     // frame.
