@@ -25,7 +25,7 @@
 
 #include "gtest/gtest.h"
 #include "aom_dsp_rtcd.h"
-#include "EbDefinitions.h"
+#include "definitions.h"
 #include "random.h"
 #include "util.h"
 namespace {
@@ -61,15 +61,8 @@ using CFL_PRED_LBD = void (*)(const int16_t *pred_buf_q3, uint8_t *pred,
  * BitDepth: 8bit and 10bit
  */
 template <typename Sample, typename FuncType>
-class CflPredTest {
+class CflPredTest : public ::testing::TestWithParam<FuncType> {
   public:
-    CflPredTest() {
-        bd_ = 8;
-        ref_func_ = nullptr;
-        tst_func_ = nullptr;
-        common_init();
-    }
-
     virtual ~CflPredTest() {
     }
 
@@ -156,30 +149,44 @@ class LbdCflPredTest : public CflPredTest<uint8_t, CFL_PRED_LBD> {
     LbdCflPredTest() {
         bd_ = 8;
         ref_func_ = svt_cfl_predict_lbd_c;
-        tst_func_ = svt_cfl_predict_lbd_avx2;
+        tst_func_ = GetParam();
         common_init();
     }
 };
+GTEST_ALLOW_UNINSTANTIATED_PARAMETERIZED_TEST(LbdCflPredTest);
+
+TEST_P(LbdCflPredTest, MatchTest) {
+    RunAllTest();
+}
+#ifdef ARCH_X86_64
+INSTANTIATE_TEST_SUITE_P(AVX2, LbdCflPredTest,
+                         ::testing::Values(svt_cfl_predict_lbd_avx2));
+#endif  // ARCH_X86_64
+
+#ifdef ARCH_AARCH64
+INSTANTIATE_TEST_SUITE_P(NEON, LbdCflPredTest,
+                         ::testing::Values(svt_aom_cfl_predict_lbd_neon));
+#endif  // ARCH_AARCH64
 
 class HbdCflPredTest : public CflPredTest<uint16_t, CFL_PRED_HBD> {
   public:
     HbdCflPredTest() {
         bd_ = 10;
         ref_func_ = svt_cfl_predict_hbd_c;
-        tst_func_ = svt_cfl_predict_hbd_avx2;
+        tst_func_ = GetParam();
         common_init();
     }
 };
+GTEST_ALLOW_UNINSTANTIATED_PARAMETERIZED_TEST(HbdCflPredTest);
 
-#define TEST_CLASS(tc_name, type_name)     \
-    TEST(tc_name, match_test) {            \
-        type_name *test = new type_name(); \
-        test->RunAllTest();                \
-        delete test;                       \
-    }
+TEST_P(HbdCflPredTest, MatchTest) {
+    RunAllTest();
+}
 
-TEST_CLASS(LbdCflPredMatchTest, LbdCflPredTest)
-TEST_CLASS(HbdCflPredMatchTest, HbdCflPredTest)
+#ifdef ARCH_X86_64
+INSTANTIATE_TEST_SUITE_P(AVX2, HbdCflPredTest,
+                         ::testing::Values(svt_cfl_predict_hbd_avx2));
+#endif  // ARCH_X86_64
 
 typedef void (*AomUpsampledPredFunc)(MacroBlockD *,
                                      const struct AV1Common *const, int, int,
@@ -216,10 +223,10 @@ class AomUpsampledPredTest
         memset(comp_pred_ref_, 1, sizeof(comp_pred_ref_));
         memset(comp_pred_tst_, 1, sizeof(comp_pred_tst_));
 
-        // Function svt_aom_upsampled_pred_sse2 call inside function pointer
-        // which have to be set properly
-        // by svt_aom_setup_common_rtcd_internal(), we want to test intrinsic
-        // version of it, so AVX2 flag is necessary
+        // Function svt_aom_upsampled_pred call inside function pointer
+        // which have to be set properly by
+        // svt_aom_setup_common_rtcd_internal(), we want to test intrinsic
+        // version of it, so feature flag is necessary
         uint64_t EbCpuFlags = TEST_GET_PARAM(5);
         svt_aom_setup_common_rtcd_internal(EbCpuFlags);
 
@@ -271,14 +278,27 @@ TEST_P(AomUpsampledPredTest, MatchTest) {
     run_test();
 }
 
-INSTANTIATE_TEST_CASE_P(
-    UPSAMPLED_PRED_TEST, AomUpsampledPredTest,
+#ifdef ARCH_X86_64
+INSTANTIATE_TEST_SUITE_P(
+    SSE2, AomUpsampledPredTest,
+    ::testing::Combine(
+        ::testing::Range(BLOCK_4X4, BlockSizeS_ALL),
+        ::testing::Values(svt_aom_upsampled_pred_sse2),
+        ::testing::Values((int)USE_2_TAPS, (int)USE_4_TAPS, (int)USE_8_TAPS),
+        ::testing::Values(0, 1, 2), ::testing::Values(0, 1, 2),
+        ::testing::Values(EB_CPU_FLAGS_SSSE3, EB_CPU_FLAGS_AVX2)));
+#endif  // ARCH_X86_64
+
+#ifdef ARCH_AARCH64
+INSTANTIATE_TEST_SUITE_P(
+    NEON, AomUpsampledPredTest,
     ::testing::Combine(::testing::Range(BLOCK_4X4, BlockSizeS_ALL),
-                       ::testing::Values(svt_aom_upsampled_pred_sse2),
-                       ::testing::Values(USE_2_TAPS, USE_4_TAPS, USE_8_TAPS),
+                       ::testing::Values(svt_aom_upsampled_pred_neon),
+                       ::testing::Values((int)USE_2_TAPS, (int)USE_4_TAPS,
+                                         (int)USE_8_TAPS),
                        ::testing::Values(0, 1, 2), ::testing::Values(0, 1, 2),
-                       ::testing::Values(EB_CPU_FLAGS_SSSE3,
-                                         EB_CPU_FLAGS_AVX2)));
+                       ::testing::Values(EB_CPU_FLAGS_NEON)));
+#endif  // ARCH_AARCH64
 
 typedef void (*CflLumaSubsamplingLbdFunc)(const uint8_t *, int32_t, int16_t *,
                                           int32_t, int32_t);
@@ -334,16 +354,19 @@ class CflLumaSubsamplingLbdTest
   private:
     SVTRandom rnd_;
 };
+GTEST_ALLOW_UNINSTANTIATED_PARAMETERIZED_TEST(CflLumaSubsamplingLbdTest);
 
 TEST_P(CflLumaSubsamplingLbdTest, MatchTest) {
     run_test();
 }
 
-INSTANTIATE_TEST_CASE_P(
-    CFL_LUMA_SUBSAMPLING_LBD, CflLumaSubsamplingLbdTest,
+#ifdef ARCH_X86_64
+INSTANTIATE_TEST_SUITE_P(
+    AVX2, CflLumaSubsamplingLbdTest,
     ::testing::Combine(
         ::testing::Range(BLOCK_4X4, BlockSizeS_ALL),
         ::testing::Values(svt_cfl_luma_subsampling_420_lbd_avx2)));
+#endif
 
 typedef void (*CflLumaSubsamplingHbdFunc)(const uint16_t *, int32_t, int16_t *,
                                           int32_t, int32_t);
@@ -399,15 +422,18 @@ class CflLumaSubsamplingHbdTest
   private:
     SVTRandom rnd_;
 };
+GTEST_ALLOW_UNINSTANTIATED_PARAMETERIZED_TEST(CflLumaSubsamplingHbdTest);
 
 TEST_P(CflLumaSubsamplingHbdTest, MatchTest) {
     run_test();
 }
 
-INSTANTIATE_TEST_CASE_P(
-    CFL_LUMA_SUBSAMPLING_HBD, CflLumaSubsamplingHbdTest,
+#ifdef ARCH_X86_64
+INSTANTIATE_TEST_SUITE_P(
+    AVX2, CflLumaSubsamplingHbdTest,
     ::testing::Combine(
         ::testing::Range(BLOCK_4X4, BlockSizeS_ALL),
         ::testing::Values(svt_cfl_luma_subsampling_420_hbd_avx2)));
+#endif  // ARCH_X86_64
 
 }  // namespace
