@@ -23,7 +23,7 @@
 
 #include "gtest/gtest.h"
 #include "aom_dsp_rtcd.h"
-#include "EbDefinitions.h"
+#include "definitions.h"
 #include "random.h"
 
 namespace {
@@ -256,13 +256,14 @@ class DrPredTest {
     FuncType tst_func_;
 };
 
-class LowbdZ1PredTest : public DrPredTest<uint8_t, Z1_LBD> {
+class LowbdZ1PredTest : public DrPredTest<uint8_t, Z1_LBD>,
+                        public ::testing::TestWithParam<Z1_LBD> {
   public:
     LowbdZ1PredTest() {
         start_angle_ = z1_start_angle;
         stop_angle_ = start_angle_ + 90;
         ref_func_ = svt_av1_dr_prediction_z1_c;
-        tst_func_ = svt_av1_dr_prediction_z1_avx2;
+        tst_func_ = GetParam();
         bd_ = 8;
 
         common_init();
@@ -291,13 +292,28 @@ class LowbdZ1PredTest : public DrPredTest<uint8_t, Z1_LBD> {
     }
 };
 
-class LowbdZ2PredTest : public DrPredTest<uint8_t, Z2_LBD> {
+TEST_P(LowbdZ1PredTest, MatchTest) {
+    RunAllTest();
+}
+
+#ifdef ARCH_X86_64
+INSTANTIATE_TEST_SUITE_P(AVX2, LowbdZ1PredTest,
+                         ::testing::Values(svt_av1_dr_prediction_z1_avx2));
+#endif  // ARCH_X86_64
+
+#ifdef ARCH_AARCH64
+INSTANTIATE_TEST_SUITE_P(NEON, LowbdZ1PredTest,
+                         ::testing::Values(svt_av1_dr_prediction_z1_neon));
+#endif  // ARCH_AARCH64
+
+class LowbdZ2PredTest : public DrPredTest<uint8_t, Z2_LBD>,
+                        public ::testing::TestWithParam<Z2_LBD> {
   public:
     LowbdZ2PredTest() {
         start_angle_ = z2_start_angle;
         stop_angle_ = start_angle_ + 90;
         ref_func_ = svt_av1_dr_prediction_z2_c;
-        tst_func_ = svt_av1_dr_prediction_z2_avx2;
+        tst_func_ = GetParam();
         bd_ = 8;
 
         common_init();
@@ -328,13 +344,28 @@ class LowbdZ2PredTest : public DrPredTest<uint8_t, Z2_LBD> {
     }
 };
 
-class LowbdZ3PredTest : public DrPredTest<uint8_t, Z3_LBD> {
+TEST_P(LowbdZ2PredTest, MatchTest) {
+    RunAllTest();
+}
+
+#ifdef ARCH_X86_64
+INSTANTIATE_TEST_SUITE_P(AVX2, LowbdZ2PredTest,
+                         ::testing::Values(svt_av1_dr_prediction_z2_avx2));
+#endif  // ARCH_X86_64
+
+#ifdef ARCH_AARCH64
+INSTANTIATE_TEST_SUITE_P(NEON, LowbdZ2PredTest,
+                         ::testing::Values(svt_av1_dr_prediction_z2_neon));
+#endif  // ARCH_AARCH64
+
+class LowbdZ3PredTest : public DrPredTest<uint8_t, Z3_LBD>,
+                        public ::testing::TestWithParam<Z3_LBD> {
   public:
     LowbdZ3PredTest() {
         start_angle_ = z3_start_angle;
         stop_angle_ = start_angle_ + 90;
         ref_func_ = svt_av1_dr_prediction_z3_c;
-        tst_func_ = svt_av1_dr_prediction_z3_avx2;
+        tst_func_ = GetParam();
         bd_ = 8;
 
         common_init();
@@ -363,24 +394,28 @@ class LowbdZ3PredTest : public DrPredTest<uint8_t, Z3_LBD> {
     }
 };
 
-#define TEST_CLASS(tc_name, type_name)        \
-    TEST(tc_name, match_test) {               \
-        type_name *dr_test = new type_name(); \
-        dr_test->RunAllTest();                \
-        delete dr_test;                       \
-    }
+TEST_P(LowbdZ3PredTest, MatchTest) {
+    RunAllTest();
+}
 
-TEST_CLASS(LowbdDrZ1Test, LowbdZ1PredTest)
-TEST_CLASS(LowbdDrZ2Test, LowbdZ2PredTest)
-TEST_CLASS(LowbdDrZ3Test, LowbdZ3PredTest)
+#ifdef ARCH_X86_64
+INSTANTIATE_TEST_SUITE_P(AVX2, LowbdZ3PredTest,
+                         ::testing::Values(svt_av1_dr_prediction_z3_avx2));
+#endif  // ARCH_X86_64
 
-class HighbdZ1PredTest : public DrPredTest<uint16_t, Z1_HBD> {
+#ifdef ARCH_AARCH64
+INSTANTIATE_TEST_SUITE_P(NEON, LowbdZ3PredTest,
+                         ::testing::Values(svt_av1_dr_prediction_z3_neon));
+#endif  // ARCH_AARCH64
+
+class HighbdZ1PredTest : public DrPredTest<uint16_t, Z1_HBD>,
+                         public ::testing::TestWithParam<Z1_HBD> {
   public:
     HighbdZ1PredTest() {
         start_angle_ = z1_start_angle;
         stop_angle_ = start_angle_ + 90;
         ref_func_ = svt_av1_highbd_dr_prediction_z1_c;
-        tst_func_ = svt_av1_highbd_dr_prediction_z1_avx2;
+        tst_func_ = GetParam();
         bd_ = 10;
 
         common_init();
@@ -410,14 +445,26 @@ class HighbdZ1PredTest : public DrPredTest<uint16_t, Z1_HBD> {
                   bd_);
     }
 };
+GTEST_ALLOW_UNINSTANTIATED_PARAMETERIZED_TEST(HighbdZ1PredTest);
 
-class HighbdZ2PredTest : public DrPredTest<uint16_t, Z2_HBD> {
+TEST_P(HighbdZ1PredTest, MatchTest) {
+    RunAllTest();
+}
+
+#ifdef ARCH_X86_64
+INSTANTIATE_TEST_SUITE_P(
+    AVX2, HighbdZ1PredTest,
+    ::testing::Values(svt_av1_highbd_dr_prediction_z1_avx2));
+#endif  // ARCH_X86_64
+
+class HighbdZ2PredTest : public DrPredTest<uint16_t, Z2_HBD>,
+                         public ::testing::TestWithParam<Z2_HBD> {
   public:
     HighbdZ2PredTest() {
         start_angle_ = z2_start_angle;
         stop_angle_ = start_angle_ + 90;
         ref_func_ = svt_av1_highbd_dr_prediction_z2_c;
-        tst_func_ = svt_av1_highbd_dr_prediction_z2_avx2;
+        tst_func_ = GetParam();
         bd_ = 10;
 
         common_init();
@@ -449,14 +496,26 @@ class HighbdZ2PredTest : public DrPredTest<uint16_t, Z2_HBD> {
                   bd_);
     }
 };
+GTEST_ALLOW_UNINSTANTIATED_PARAMETERIZED_TEST(HighbdZ2PredTest);
 
-class HighbdZ3PredTest : public DrPredTest<uint16_t, Z3_HBD> {
+TEST_P(HighbdZ2PredTest, MatchTest) {
+    RunAllTest();
+}
+
+#ifdef ARCH_X86_64
+INSTANTIATE_TEST_SUITE_P(
+    AVX2, HighbdZ2PredTest,
+    ::testing::Values(svt_av1_highbd_dr_prediction_z2_avx2));
+#endif  // ARCH_X86_64
+
+class HighbdZ3PredTest : public DrPredTest<uint16_t, Z3_HBD>,
+                         public ::testing::TestWithParam<Z3_HBD> {
   public:
     HighbdZ3PredTest() {
         start_angle_ = z3_start_angle;
         stop_angle_ = start_angle_ + 90;
         ref_func_ = svt_av1_highbd_dr_prediction_z3_c;
-        tst_func_ = svt_av1_highbd_dr_prediction_z3_avx2;
+        tst_func_ = GetParam();
         bd_ = 10;
 
         common_init();
@@ -486,9 +545,15 @@ class HighbdZ3PredTest : public DrPredTest<uint16_t, Z3_HBD> {
                   bd_);
     }
 };
+GTEST_ALLOW_UNINSTANTIATED_PARAMETERIZED_TEST(HighbdZ3PredTest);
 
-TEST_CLASS(HighbdDrZ1Test, HighbdZ1PredTest)
-TEST_CLASS(HighbdDrZ2Test, HighbdZ2PredTest)
-TEST_CLASS(HighbdDrZ3Test, HighbdZ3PredTest)
+TEST_P(HighbdZ3PredTest, MatchTest) {
+    RunAllTest();
+}
 
+#ifdef ARCH_X86_64
+INSTANTIATE_TEST_SUITE_P(
+    AVX2, HighbdZ3PredTest,
+    ::testing::Values(svt_av1_highbd_dr_prediction_z3_avx2));
+#endif  // ARCH_X86_64
 }  // namespace
